@@ -21,6 +21,8 @@ from .endpoint_headers_in import EndpointHeadersIn
 from .endpoint_headers_in_headers import EndpointHeadersInHeaders
 from .endpoint_headers_out import EndpointHeadersOut
 from .endpoint_headers_out_headers import EndpointHeadersOutHeaders
+from .endpoint_headers_patch_in import EndpointHeadersPatchIn
+from .endpoint_headers_patch_in_headers import EndpointHeadersPatchInHeaders
 from .endpoint_in import EndpointIn
 from .endpoint_message_out import EndpointMessageOut
 from .endpoint_message_out_payload import EndpointMessageOutPayload
@@ -74,6 +76,8 @@ from .message_attempt_failed_data import MessageAttemptFailedData
 from .message_attempt_failing_event import MessageAttemptFailingEvent
 from .message_attempt_failing_event_data import MessageAttemptFailingEventData
 from .message_attempt_failing_event_type import MessageAttemptFailingEventType
+from .message_attempt_headers_out import MessageAttemptHeadersOut
+from .message_attempt_headers_out_sentheaders import MessageAttemptHeadersOutSentheaders
 from .message_attempt_out import MessageAttemptOut
 from .message_attempt_trigger_type import MessageAttemptTriggerType
 from .message_endpoint_out import MessageEndpointOut
